import moment from 'moment';
import formatRelativeDatetime from './formatRelativeDatetime';


test('default same day', () => {
    const timestamp = moment().startOf('day').format('x');
    const date = formatRelativeDatetime(timestamp);

    expect(date).toBe('Idag 00:00');
});

test('default next day', () => {
    const timestamp = moment().add(1, 'day').startOf('day').format('x');
    const date = formatRelativeDatetime(timestamp);

    expect(date).toBe('Imorgon 00:00');
});

test('default last day', () => {
    const timestamp = Number(moment().subtract(1, 'day').startOf('day').format('x'));
    const date = formatRelativeDatetime(timestamp);

    expect(date).toBe('Igår 00:00');
});

test('english same day', () => {
    const timestamp = Number(moment().startOf('day').format('x'));
    const date = formatRelativeDatetime(timestamp, { locale: 'en' });

    expect(date).toBe('Today at 12:00 AM');
});

test('default next day', () => {
    const timestamp = Number(moment().add(1, 'day').startOf('day').format('x'));
    const date = formatRelativeDatetime(timestamp, { locale: 'en' });

    expect(date).toBe('Tomorrow at 12:00 AM');
});

test('default last day', () => {
    const timestamp = Number(moment().subtract(1, 'day').startOf('day').format('x'));
    const date = formatRelativeDatetime(timestamp, { locale: 'en' });

    expect(date).toBe('Yesterday at 12:00 AM');
});

test('reference', () => {
    const timestamp = Number(moment().startOf('day').format('x'));
    const reference = Number(moment().startOf('day').subtract(1, 'day').format('x'));
    const date = formatRelativeDatetime(timestamp, { reference });

    expect(date).toBe('Imorgon 00:00');
});
